<?php

namespace CRM\Service;

use CRM\Factory\CrmModalidadeDePagamentoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmModalidadeDePagamentoService
{

    protected $CrmModalidadeDePagamentoFactory;
    protected $environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $environment, NewCode $newCode, EntityManager $entityManager, CrmModalidadeDePagamentoFactory $CrmModalidadeDePagamentoFactory)
    {
        $this->CrmModalidadeDePagamentoFactory    = $CrmModalidadeDePagamentoFactory;
        $this->environment                        = $environment;
        $this->newCode                            = $newCode;
        $this->connection                         = $entityManager->getConnection();
    }

    public function getModalityPaymentService()
    {
        return $this->CrmModalidadeDePagamentoFactory->getModalityPaymentFactory();
    }

    public function formOfPaymentService()
    {
        return $this->CrmModalidadeDePagamentoFactory->formOfPaymentFactory();
    }

    public function typeOfPaymentService()
    {
        return $this->CrmModalidadeDePagamentoFactory->typeOfPaymentFactory();
    }

    public function saveNewModalityPaymentService($rows)
    {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $this->connection->beginTransaction();

        try {

            $cdmodpgto = $this->newCode->getCodeByTableName("MODPGTO", $nrorg, 1, 5, false);
            $params = array(
                "CDMODPGTO"         => $cdmodpgto,
                "DSMODPGTO"         => $rows["DSMODPGTO"],
                "IDATIVO"           => $rows["IDATIVO"],
                "CDFORMPGTO"        => $rows["CDFORMPGTO"],
                "IDTPFORPGTOMOD"    => $rows["IDTPFORPGTOMOD"],
                "NRDIAPGFIXMOD"     => $rows["NRDIAPGFIXMOD"],
                "NRPARCPGTOMOD"     => isset($rows["NRPARCPGTOMOD"]) ? $rows["NRPARCPGTOMOD"] : null,
                "IDUTDIAPAGMOD"     => $rows["IDUTDIAPAGMOD"],
                "VRFATAJUPARC"      => $rows["VRFATAJUPARC"],
                "CDTIPORECE"        => $rows["CDTIPORECE"],
                "VRPEDESMODPG"      => $rows["VRPEDESMODPG"],
                "IDLANCPEDMOD"      => $rows["IDLANCPEDMOD"],
                "VRFATORCOMISSAO"   => $rows["VRFATORCOMISSAO"],
                "NRORG"             => $nrorg,
                "NRORGINCLUSAO"     => $nrorg,
                "NRORGULTATU"       => $nrorg,
                "CDOPERINCLUSAO"    => $cdoperador,
                "CDOPERULTATU"      => $cdoperador,
            );

            $this->CrmModalidadeDePagamentoFactory->insertNewModalityPaymentFactory($params);

            $this->connection->commit();
        } catch (\Exception $e) {

            $this->connection->rollback();
            throw $e;
        }
    }

    public function updateModalityPaymentService($rows)
    {

        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $this->connection->beginTransaction();
        try {

            $params = array(
                "CDMODPGTO"         => $rows["CDMODPGTO"],
                "IDATIVO"           => $rows["IDATIVO"],
                "DSMODPGTO"         => $rows["DSMODPGTO"],
                "CDFORMPGTO"        => $rows["CDFORMPGTO"],
                "IDTPFORPGTOMOD"    => $rows["IDTPFORPGTOMOD"],
                "NRDIAPGFIXMOD"     => $rows["NRDIAPGFIXMOD"],
                "NRPARCPGTOMOD"     => isset($rows["NRPARCPGTOMOD"]) ? $rows["NRPARCPGTOMOD"] : null,
                "IDUTDIAPAGMOD"     => $rows["IDUTDIAPAGMOD"],
                "VRFATAJUPARC"      => $rows["VRFATAJUPARC"],
                "CDTIPORECE"        => $rows["CDTIPORECE"],
                "VRPEDESMODPG"      => $rows["VRPEDESMODPG"],
                "IDLANCPEDMOD"      => $rows["IDLANCPEDMOD"],
                "VRFATORCOMISSAO"   => $rows["VRFATORCOMISSAO"],
                "NRORG"             => $nrorg,
                "NRORGINCLUSAO"     => $nrorg,
                "NRORGULTATU"       => $nrorg,
                "CDOPERULTATU"      => $cdoperador,
                "CDOPERINCLUSAO"    => $cdoperador,
            );

            $this->CrmModalidadeDePagamentoFactory->updateModalityPaymentFactory($params);

            $this->connection->commit();
        } catch (\Exception $e) {

            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteModalityPaymentService($row)
    {
        $this->connection->beginTransaction();
        try {
                $relationships = $this->findRelationship($row);

                if ($relationships[0]["CDMODPGTO"] == 0) {
                    $params = implode(',', $row["CDMD"]);                    
                    $this->CrmModalidadeDePagamentoFactory->deleteModalityPaymentFactory($params);
                } else {

                    throw new \Exception("Esta Modalidade De Pagamento Não Pode Ser Excluida, Pois Já Está Sendo Utilizada!");
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function findRelationship($row)
    {
        $params = array(
            "CDMODPGTO" => implode(',', $row["CDMD"]),
        );
        return $this->CrmModalidadeDePagamentoFactory->findRelationshipFactory($params);
    }
}