import { Utilities } from '@/util/Utilities';
import { Button, DialogService, LoadingService } from '@zeedhi/common';
import { Http, IEventParam, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmFaseDeNegociacaoController {
  public addNewRow({ component }: IEventParam<TekGrid>) {
    const newId = 0;
    component.addNewRow({ NRSEQFASENEGO: newId, IDATIVO: 'S' }, 'start');
  }

  public saveNegotiationPhase({ component, event }: IEventParam<TekGrid>) {
    event?.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveNegotiationPhase', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public messageDeleteNegotiationPhase({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmFaseDeNegociacaoController.deleteNegotiationPhase');
  }

  public deleteNegotiationPhase() {
    const component = Metadata.getInstance<TekGrid>('tek_grid_crm_fase_de_negociacao_grid');
    LoadingService.show();
    Http.post('/deleteNegotiationPhase', {
      NRSQ: component.selectedRows.map((element: any) => element.NRSEQFASENEGO),
    }).then(() => {
      Utilities.showSuccessMessage();
      component.datasource.get();
    }).catch((error: any) => {
      error.showErrorMessage();
    }).finally(() => {
      component.selectedRows = [];
      LoadingService.hide();
      DialogService.hide();
    });
  }

  public canEditRow({ row }: any) {
    return row['.__added_row'] === true;
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }
}
