import { Utilities } from '@/util/Utilities';
import {
  Button,
  DialogService,
  Form, LoadingService, Modal, ModalService, Select, Tabs, TextInput,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmModalidadeDePagamentoController {
  private modalAdicionar!: Modal;

  public visibilidade: boolean = true;

  public currentRow: any = {};

  get visibilidadeDoFrame() {
    return !this.visibilidade;
  }

  public async openModalNewModalityPayment() {
    const modalPath = 'crm_modalidade_de_pagamento/Modal/crm_modalidade_de_pagamento_modal';
    this.modalAdicionar = await ModalService.createFromJson(modalPath, true);
    await this.modalAdicionar.show();
  }

  public closeModal() {
    this.modalAdicionar.hide();
    this.modalAdicionar?.destroy();
  }

  public clickButtonToExpand({ component }: any) {
    const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
    form.isVisible = !form.isVisible;

    component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
  }

  public changeModality({ component }: any) {
    const formPayment = Metadata.getInstance<Select>('rowformFormaDePagamento');
    const inputPayment = Metadata.getInstance<Select>('NMFORMPGTO-MODAL');
    const formFixedPayment = Metadata.getInstance<Select>('rowformPagementoFixo');
    const inputPayDay = Metadata.getInstance<Select>('NRDIAPGFIXMOD-MODAL');
    const inputInstallments = Metadata.getInstance<Select>('NRPARCPGTOMOD-MODAL');
    const inputPostponedInstallments = Metadata.getInstance<Select>('IDUTDIAPAGMOD-MODAL');
    if (component.value === 'V') {
      formPayment.isVisible = true;
      inputPayment.isVisible = true;
      formFixedPayment.isVisible = false;
      inputPayDay.isVisible = false;
      inputInstallments.isVisible = false;
      inputPostponedInstallments.isVisible = false;
    } else if (component.value === 'F') {
      formFixedPayment.isVisible = true;
      inputPayDay.isVisible = true;
      inputInstallments.isVisible = true;
      inputPostponedInstallments.isVisible = true;
      formPayment.isVisible = false;
      inputPayment.isVisible = false;
    } else {
      inputPayDay.value = null;
      inputInstallments.value = null;
      inputPostponedInstallments.value = null;
      inputPayment.value = null;
      formFixedPayment.isVisible = false;
      inputPayDay.isVisible = false;
      inputInstallments.isVisible = false;
      inputPostponedInstallments.isVisible = false;
      formPayment.isVisible = false;
      inputPayment.isVisible = false;
    }
  }

  public saveNewModalityPayment() {
    const formModalPayMode = Metadata.getInstance<Form>('form_ModalidadeDePagamento');
    const formModalFormPay = Metadata.getInstance<Form>('formFormaDePagamento');
    const formModalFixedPay = Metadata.getInstance<Form>('formPagementoFixo');
    const formModalAddData = Metadata.getInstance<Form>('formDadosAdicional');
    const grid = Metadata.getInstance<TekGrid>('tek_grid_crm_modalidade_de_pagamento_grid');
    const params = {
      CDMODPGTO: Metadata.getInstance<Select>('CDMODPGTO-MODAL').value,
      IDATIVO: Metadata.getInstance<Select>('IDATIVO-MODAL').value,
      DSMODPGTO: Metadata.getInstance<Select>('DSMODPGTO-MODAL').value,
      VRFATAJUPARC: Metadata.getInstance<Select>('VRFATAJUPARC-MODAL').value,
      VRPEDESMODPG: Metadata.getInstance<Select>('VRPEDESMODPG-MODAL').value,
      NMTIPORECE: Metadata.getInstance<Select>('NMTIPORECE-MODAL').value,
      CDTIPORECE: Metadata.getInstance<Select>('NMTIPORECE-MODAL').value,
      IDTPFORPGTOMOD: Metadata.getInstance<Select>('IDTPFORPGTOMOD-MODAL').value,
      NMFORMPGTO: Metadata.getInstance<Select>('NMFORMPGTO-MODAL').value,
      CDFORMPGTO: Metadata.getInstance<Select>('NMFORMPGTO-MODAL').value,
      NRDIAPGFIXMOD: Metadata.getInstance<Select>('NRDIAPGFIXMOD-MODAL').value,
      NRPARCPGTOMOD: Metadata.getInstance<Select>('NRPARCPGTOMOD-MODAL').value,
      IDUTDIAPAGMOD: Metadata.getInstance<Select>('IDUTDIAPAGMOD-MODAL').value,
      IDLANCPEDMOD: Metadata.getInstance<Select>('IDLANCPEDMOD-MODAL').value,
      VRFATORCOMISSAO: Metadata.getInstance<Select>('VRFATORCOMISSAO-MODAL').value,

    };
    if (
      Utilities.validateForm(formModalPayMode)
      && Utilities.validateForm(formModalFormPay)
      && Utilities.validateForm(formModalFixedPay)
      && Utilities.validateForm(formModalAddData)
    ) {
      LoadingService.show();
      Http.post('/saveNewModalityPayment', params).then(() => {
        this.closeModal();
        grid.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }

  public messageDeleteModalityPayment({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmModalidadeDePagamentoController.deleteModalityPayment');
  }

  public deleteModalityPayment() {
    const component = Metadata.getInstance<TekGrid>('tek_grid_crm_modalidade_de_pagamento_grid');
    LoadingService.show();
    Http.post('/deleteModalityPayment', {
      CDMD: component.selectedRows.map((element: any) => element.CDMODPGTO),
    }).then(() => {
      Utilities.showSuccessMessage();
      component.datasource.get();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      component.selectedRows = [];
      LoadingService.hide();
      DialogService.hide();
    });
  }

  public voltarPaginaInicial() {
    this.visibilidade = true;
  }

  public visualizarDadosGerais({ row }: any) {
    this.visibilidade = false;
    this.currentRow = row;
    this.recarregarTabs();
  }

  public recarregarTabs(): void {
    const setOfTabs = Metadata.getInstance<Tabs>('tabs-modalidade-pagamento');
    if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab-general-data') {
      this.montarInformacoesDadosGerais();
    }
  }

  public montarInformacoesDadosGerais() {
    Metadata.getInstance<TextInput>('IDATIVO').value = this.currentRow.IDATIVO;
    Metadata.getInstance<Select>('IDTPFORPGTOMOD').value = this.currentRow.IDTPFORPGTOMOD;
    Metadata.getInstance<TextInput>('CDMODPGTO').value = this.currentRow.CDMODPGTO;
    Metadata.getInstance<TextInput>('DSMODPGTO').value = this.currentRow.DSMODPGTO;
    Metadata.getInstance<TextInput>('VRFATAJUPARC').value = this.currentRow.VRFATAJUPARC;
    Metadata.getInstance<TextInput>('VRPEDESMODPG').value = this.currentRow.VRPEDESMODPG;
    Metadata.getInstance<Select>('NMFORMPGTO').value = this.currentRow.CDFORMPGTO;
    Metadata.getInstance<Select>('NMFORMPGTO').value = this.currentRow.NMFORMPGTO;
    Metadata.getInstance<Select>('NMTIPORECE').value = this.currentRow.CDTIPORECE;
    Metadata.getInstance<Select>('NMTIPORECE').value = this.currentRow.NMTIPORECE;
    Metadata.getInstance<Select>('NRDIAPGFIXMOD').value = this.currentRow.NRDIAPGFIXMOD;
    Metadata.getInstance<Select>('NRPARCPGTOMOD').value = this.currentRow.NRPARCPGTOMOD;
    Metadata.getInstance<Select>('IDUTDIAPAGMOD').value = this.currentRow.IDUTDIAPAGMOD;
    Metadata.getInstance<Select>('IDLANCPEDMOD').value = this.currentRow.IDLANCPEDMOD;
    Metadata.getInstance<Select>('VRFATORCOMISSAO').value = this.currentRow.VRFATORCOMISSAO;
  }

  public changeModalityTab({ component }: any) {
    const inputPaymentTab = Metadata.getInstance<Select>('NMFORMPGTO');
    const inputPayDayTab = Metadata.getInstance<Select>('NRDIAPGFIXMOD');
    const inputInstallmentsTab = Metadata.getInstance<Select>('NRPARCPGTOMOD');
    const inputPostponedInstallmentsTab = Metadata.getInstance<Select>('IDUTDIAPAGMOD');
    if (component.value === 'V') {
      inputPaymentTab.isVisible = true;
      inputPayDayTab.isVisible = false;
      inputInstallmentsTab.isVisible = false;
      inputPostponedInstallmentsTab.isVisible = false;
    } else if (component.value === 'F') {
      inputPayDayTab.isVisible = true;
      inputInstallmentsTab.isVisible = true;
      inputPostponedInstallmentsTab.isVisible = true;
      inputPaymentTab.isVisible = false;
    } else {
      inputPayDayTab.value = null;
      inputInstallmentsTab.value = null;
      inputPostponedInstallmentsTab.value = null;
      inputPaymentTab.value = null;
      inputPayDayTab.isVisible = false;
      inputInstallmentsTab.isVisible = false;
      inputPostponedInstallmentsTab.isVisible = false;
      inputPaymentTab.isVisible = false;
    }
  }

  public saveEditModalityPayment() {
    LoadingService.show();
    const grid = Metadata.getInstance<TekGrid>('tek_grid_crm_modalidade_de_pagamento_grid');
    const params = {
      CDMODPGTO: Metadata.getInstance<Select>('CDMODPGTO').value,
      IDATIVO: Metadata.getInstance<Select>('IDATIVO').value,
      DSMODPGTO: Metadata.getInstance<Select>('DSMODPGTO').value,
      VRFATAJUPARC: Metadata.getInstance<Select>('VRFATAJUPARC').value,
      VRPEDESMODPG: Metadata.getInstance<Select>('VRPEDESMODPG').value,
      NMTIPORECE: Metadata.getInstance<Select>('NMTIPORECE').value,
      CDTIPORECE: Metadata.getInstance<Select>('NMTIPORECE').value,
      IDTPFORPGTOMOD: Metadata.getInstance<Select>('IDTPFORPGTOMOD').value,
      NMFORMPGTO: Metadata.getInstance<Select>('NMFORMPGTO').value,
      CDFORMPGTO: Metadata.getInstance<Select>('NMFORMPGTO').value,
      NRDIAPGFIXMOD: Metadata.getInstance<Select>('NRDIAPGFIXMOD').value,
      NRPARCPGTOMOD: Metadata.getInstance<Select>('NRPARCPGTOMOD').value,
      IDUTDIAPAGMOD: Metadata.getInstance<Select>('IDUTDIAPAGMOD').value,
      IDLANCPEDMOD: Metadata.getInstance<Select>('IDLANCPEDMOD').value,
      VRFATORCOMISSAO: Metadata.getInstance<Select>('VRFATORCOMISSAO').value,
    };
    Http.post('/updateModalityPayment', params).then(() => {
      this.recarregarTabs();
      grid.reload();
      this.voltarPaginaInicial();
      Utilities.showSuccessMessage();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
    });
  }

  public reloadGrid(grid: any) {
    const filterButton = Metadata.getInstance<Button>(`${grid}_refreshButton`);
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }
}
